# ЧАСТО ЗАДАВАЕМЫЕ ВОПРОСЫ

## Является ли Vyro заменой FastAPI?

Vyro нацелен на Python DX с механизмом выполнения Rust. Оценивайте свою рабочую нагрузку, целевые значения задержки и операционную модель.

## Почему в документации упоминается `python -m vyro`?

`vyro` — основная команда для конечных пользователей. `python -m vyro` — это запасной вариант, когда PATH оболочки еще не настроен.

## Должны ли пользователи запускать команды `scripts.dev.*`?

Нет. Конечные пользователи должны использовать `vyro ...`. Сценарии разработчика — это внутренние инструменты обслуживания.

## Поддерживает ли Vyro WebSocket?

Да, через пограничные примитивы среды выполнения и обработчики WebSocket на уровне маршрута.

## Могу ли я работать на Python 3.13?

Да. Vyro нацелен на Python 3.10–3.13.